@@ -3,7 +3,9 @@ use std::ptr;
 
 use crate::error::SparseLinearAlgebraError;
 // use crate::operators::BinaryOperatorType;
-use crate::operators::{BinaryOperator, MatrixMask, OperatorOptions};
+use crate::operators::{
+    binary_operator::BinaryOperator, mask::MatrixMask, options::OperatorOptions,
+};
 use crate::sparse_matrix::SparseMatrix;
 use crate::util::{ElementIndexSelector, ElementIndexSelectorGraphblasType, IndexConversion};
 use crate::value_type::{AsBoolean, ValueType};
