@@ -3,7 +3,7 @@ use std::ptr;
 use std::marker::PhantomData;
 
 use crate::error::SparseLinearAlgebraError;
-use crate::operators::{BinaryOperator, MatrixMask, OperatorOptions};
+use crate::operators::{binary_operator::BinaryOperator, mask::MatrixMask, options::OperatorOptions};
 use crate::sparse_matrix::SparseMatrix;
 
 use crate::util::{ElementIndexSelector, ElementIndexSelectorGraphblasType, IndexConversion};
